# cfxdb

[![PyPI](https://img.shields.io/pypi/v/cfxdb.svg)](https://pypi.python.org/pypi/cfxdb)
[![Python](https://img.shields.io/pypi/pyversions/cfxdb.svg)](https://pypi.python.org/pypi/cfxdb)
[![CI](https://github.com/crossbario/cfxdb/workflows/main/badge.svg)](https://github.com/crossbario/cfxdb/actions?query=workflow%3Amain)
[![Docs](https://readthedocs.org/projects/cfxdb/badge/?version=latest)](https://cfxdb.readthedocs.io/en/latest/)
[![License](https://img.shields.io/pypi/l/cfxdb.svg)](https://github.com/crossbario/cfxdb/blob/master/LICENSE)
[![Downloads](https://img.shields.io/pypi/dm/cfxdb.svg)](https://pypi.python.org/pypi/cfxdb)

---

**cfxdb** is a Crossbar.io Python support package with core database
access classes written in native Python. The package allows direct
in-memory data access from Python programs (including Jupyter notebooks)
to CrossbarFX edge node data:

-   persisted WAMP event history
-   persisted router tracing data
-   XBR market maker transactions database
-   XBR network backend database
-   WAMP session cache
-   custom user, embedded object databases

------------------------------------------------------------------------

## Contents

::: {.toctree maxdepth="2"}
OVERVIEW.md ai/index
:::

------------------------------------------------------------------------

*Copyright (c) typedef int GmbH. Licensed under MIT. WAMP, Crossbar.io
and XBR are trademarks of typedef int GmbH (Germany).*
